@@ -132,6 +132,8 @@ class Obraz(Mail_sender):
     print("В библиотеке ", i, " текстов, где в каждом есть все буквосочетания ", str(keys))
     self._fast_print(keys, 'and')
 
+
+
   def fast_or_re(self):
     """ В self.book проводится поиск буквосочетаний и тексты, где есть буквосочетания, те тексты оставляются. Остальные - удаляются
     """
@@ -140,6 +142,7 @@ class Obraz(Mail_sender):
     self._fast_book = []
     pattern = r''
     for key in keys:
+      key = key.upper()
       if key[0] == "_":
         key = r'[^а-яА-Я]'+key[1:]
       if key[-1] == "_":
@@ -416,12 +419,12 @@ class Obraz(Mail_sender):
     
     i = 0
     num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
-    if num == "Нет".upper():
-      i = ""
     for text in self.texts_with_key_key[:h_m_with_keykey]:
       if num != "Нет".upper():
+        p = document.add_paragraph(text[0]+"  ")        
+      else:  
         i += 1
-      p = document.add_paragraph(str(i)+" "+text[0]+"  ")
+        p = document.add_paragraph(str(i)+" "+text[0]+"  ")
       p.add_run("("+text[1]+")").italic = True
     
     document.add_heading('Лучшие тексты БЕЗ ключевых буквосочетаний', level=1)
@@ -451,12 +454,12 @@ class Obraz(Mail_sender):
 
     i = 0
     num = input("Оставить нумерацию? введите Да или Нет").strip().upper()
-    if num == "Нет".upper():
-      i = ""
     for text in self._fast_book:
       if num != "Нет".upper():
+        p = document.add_paragraph(text[0]+"  ")        
+      else:  
         i += 1
-      p = document.add_paragraph(str(i)+" "+text[0]+"  ")
+        p = document.add_paragraph(str(i)+" "+text[0]+"  ")
       p.add_run("("+text[1]+")").italic = True
     
     
